%% Cauchy Argument Principle: Example 1
% This file constructs an example of the Cauchy Argument Principle.

%% Transfer Function
G = tf([1 -1],1);

%% Closed Curves, Gamma
% The curve Gamma goes from s=-jR to s=+jR along the imaginary axis and 
% then returns to s=-jR along a semicircle of radius R in the RHP.

Npts = 500;

R = 2;
Gamma1 = j*linspace(-R,0,Npts);
Gamma2 = j*linspace(0,R,Npts);

theta = linspace(pi/2,-pi/2,Npts);
Gamma3 = R*exp(j*theta);

Gamma = [Gamma1(:); Gamma2(:); Gamma3(:)];

figure(1);
clf
plot(real(Gamma1),imag(Gamma1),'r:', real(Gamma2),imag(Gamma2),'b',...
        real(Gamma3), imag(Gamma3),'g-.');
xlabel('Real Part');
ylabel('Imag. Part');
axis equal
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Label specific points and plot arrowheads 
hold on;
th1 = [];

plot(0,-R,'r.','MarkerSize',30);
th1(1) = text(-1,-0.92*R,'s_1 = -2j');
arrowhead(0,-R/2,0,0,0.4,[],'r');

plot(0,0,'b.','MarkerSize',30);
th1(2) = text(-0.8,0,'s_2 = 0');
arrowhead(0,R/2,0,R,0.4,[],'b');

plot(0,+R,'b.','MarkerSize',30);
th1(3) = text(-1,0.92*R,'s_3 = +2j');
arrowhead(R*cos(pi/4),R*sin(pi/4),...
    R*cos(pi/4-0.01),R*sin(pi/4-0.01),0.4,[],'g');

plot(+R,0,'g.','MarkerSize',30);
th1(4) = text(2.2,0,'s_4 = +2');
arrowhead(R*cos(-pi/4),R*sin(-pi/4),...
    R*cos(-pi/4-0.01),R*sin(-pi/4-0.01),0.4,[],'g');

% Plot zero of G
plot(1,0,'ko','MarkerSize',10);

hold off;

%% Mapping, G(Gamma)

G1 = freqresp(G,Gamma1);
G1 = G1(:);
G2 = freqresp(G,Gamma2);
G2 = G2(:);
G3 = freqresp(G,Gamma3);
G3 = G3(:);

figure(2);
clf
plot(real(G1),imag(G1),'r:', real(G2),imag(G2),'b',...
        real(G3), imag(G3),'g-.');
xlabel('Real Part');
ylabel('Imag. Part');
axis equal
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Label specific points and plot arrowheads 
hold on;
th2 = [];

Gs1 = evalfr(G,-j*R);
plot(real(Gs1),imag(Gs1),'r.','MarkerSize',30);
th2(1) = text(-2.4,-1.8,'G(s_1) = -1-2j');
arrowhead(-1,-R/2,-1,0,0.4,[],'r');

Gs2 = evalfr(G,0);
plot(real(Gs2),imag(Gs2),'b.','MarkerSize',30);
th2(2) = text(-2.1,0,'G(s_2) = -1');
arrowhead(-1,R/2,-1,R,0.4,[],'b');

Gs3 = evalfr(G,j*R);
Gs4 = evalfr(G,R);
plot(real(Gs3),imag(Gs3),'b.','MarkerSize',30);
th2(3) = text(-2.4,1.8,'G(s_3) = -1+2j');
arrowhead(-1+R*cos(pi/4),R*sin(pi/4),...
    -1+R*cos(pi/4-0.01),R*sin(pi/4-0.01),0.4,[],'g');

plot(real(Gs4),imag(Gs4),'g.','MarkerSize',30);
th2(4) = text(1.2,0,'G(s_4) = 1');
arrowhead(-1+R*cos(-pi/4),R*sin(-pi/4),...
    -1+R*cos(-pi/4-0.01),R*sin(-pi/4-0.01),0.4,[],'g');

hold off;


%% Save Plot
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure    
    set(th1,'FontSize',14)
    myprint(1,'CauchyEx1Gam')
        
    figure(2)
    garyfyFigure        
    set(th2,'FontSize',14)
    myprint(2,'CauchyEx1GGam')
end
