%% Extended Nyquist Theorem Example
% This file generates a Nyquist plots to demonstrate the use of the
% extended Nyquist stability theorem.


%% Nyquist Plots

% Loop, L(s)
L = tf(1,[1 0]);

% Perturb loop to evaluate at L(s+epsilon)
epsilon = -0.1;
Lepsilon = tf(1,[1 epsilon]);

Nw = 1000;
[Lre,Lim,w] = nyquist(Lepsilon,logspace(-4,3,Nw));
Lre = Lre(:); 
Lim = Lim(:);

figure(1)
clf;
plot(Lre,Lim,'b',Lre,-Lim,'b');
hold off;
xlabel('Real Part');
ylabel('Imag. Part');
title('Nyquist Diagram');
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Plot arrowheads at certain frequencies
[~,i] = min( abs(w-0.1) );
h=arrowhead(Lre(i),Lim(i),Lre(i+1),Lim(i+1),1,[],'b');
h=arrowhead(Lre(i),-Lim(i),Lre(i-1),-Lim(i-1),1,[],'b');


%% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    axis equal
    myprint(1,'ExtNyqThm')    
end
