%% Delay Margin Example
% This file computes the delay margin for two simple examples.

%% Step Response Plot: Example 1

% Design model
G = tf(1,[1 2 3 1]);

% Proportional Controller
K = 2;

% Nominal Loop L(s)=G(s)*K(s)
L = G*K;

% The allmargin command returns all phases that result in closed-loop
% poles on the imaginary axis at s=+/-jw. The phase are stored in 
% AM.PhaseMargin and the frequencies w are stored in AM.PMFrequency.
% The time delay margin is stored in AM.DelayMargin. Note that the
% delay margin is equal to the phase margin (in rads) divided by the
% phase margin frequency. This is verified below.
AM = allmargin(L);
PM = AM.PhaseMargin;
wPM = AM.PMFrequency;
DM = AM.DelayMargin;
[DM (PM*pi/180)/wPM]


% Plot step response of closed-loop with delay equal to delay margin
Gdm = G;
Gdm.InputDelay = DM;
Ldm = Gdm*K;
Tdm = feedback(Ldm,1);

[y,t] = step(Tdm,30);

figure(1)
clf;

plot(t,y);
xlabel('Time, sec')
ylabel('y');
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));


%% Step Response Plot: Example 2

% Design model
G = tf(1,[1 2 3 -1]);

% Proportional Controller
K = 2;

% Nominal Loop L(s)=G(s)*K(s)
L = G*K;

% The allmargin command returns all phases that result in closed-loop
% poles on the imaginary axis at s=+/-jw. The phase are stored in 
% AM.PhaseMargin and the frequencies w are stored in AM.PMFrequency.
% The time delay margin is stored in AM.DelayMargin. Note that the
% delay margin is equal to the phase margin (in rads) divided by the
% phase margin frequency. This is verified below.
AM = allmargin(L);
PM = AM.PhaseMargin;
wPM = AM.PMFrequency;
DM = AM.DelayMargin;
[DM (PM*pi/180)/wPM]

% Plot step response of closed-loop with delay equal to delay margin
Gdm = G;
Gdm.InputDelay = DM;
Ldm = Gdm*K;
Tdm = feedback(Ldm,1);

[y,t] = step(Tdm,40);

figure(2)
clf;

plot(t,y);
xlabel('Time, sec')
ylabel('y');
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

%% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    myprint(1,'DMStep1')
    
    figure(2)
    garyfyFigure
    myprint(2,'DMStep2')
end
