%% Phase Margin Example
% This file computes the phase margin for two simple examples.

%% Bode Plot: Example 1

% Design model
G = tf(1,[1 2 3 1]);

% Proportional Controller
K = 2;

% Nominal Loop L(s)=G(s)*K(s)
L = G*K;

% The allmargin command returns all phases that result in closed-loop
% poles on the imaginary axis at s=+/-jw. The phase are stored in 
% AM.PhaseMargin and the frequencies w are stored in AM.PMFrequency.
AM = allmargin(L);
PM = AM.PhaseMargin;
wPM = AM.PMFrequency;

% Bode Plot of nominal loop L(s)=G(s)*K(s)
w = logspace(-1,1,100);
[Lmag,Lph_deg,w] = bode(L,w);
Lmag = Lmag(:);
Lph_deg = Lph_deg(:);
Lmag_dB = 20*log10(Lmag);

figure(1)
clf;

subplot(2,1,1)
semilogx(w,Lmag_dB,'b',[wPM wPM w(1)],[-40 0 0],'k-.')
ylabel('Magnitude (dB)');
title('Bode Diagram');
grid on;
axis([w(1) w(end) -40 20]);
set(gca,'YTick',[-40 -20 -8 0 20],'LineWidth',1);

subplot(2,1,2)
semilogx(w,Lph_deg,'b',[wPM wPM w(1)],[0 -180+PM -180+PM],'k-.')
axis([w(1) w(end) -270 0]);
ylabel('Phase (deg)');
xlabel('Frequency (rad/sec)');
set(gca,'YTick',[-270 -180 -90 0],'LineWidth',1);
grid on;

%% Bode Plot: Example 2

% Design model
G = tf(1,[1 2 3 -1]);

% Proportional Controller
K = 2;

% Nominal Loop L(s)=G(s)*K(s)
L = G*K;

% The allmargin command returns all phases that result in closed-loop
% poles on the imaginary axis at s=+/-jw. The phase are stored in 
% AM.PhaseMargin and the frequencies w are stored in AM.PMFrequency.
AM = allmargin(L);
PM = AM.PhaseMargin;
wPM = AM.PMFrequency;

% Bode Plot of nominal loop L(s)=G(s)*K(s)
w = logspace(-1,1,100);
[Lmag,Lph_deg,w] = bode(L,w);
Lmag = Lmag(:);
Lph_deg = Lph_deg(:);
Lmag_dB = 20*log10(Lmag);

figure(2)
clf;

subplot(2,1,1)
semilogx(w,Lmag_dB,'b',[wPM wPM w(1)],[-40 0 0],'k-.')
ylabel('Magnitude (dB)');
title('Bode Diagram');
grid on;
axis([w(1) w(end) -40 20]);
set(gca,'YTick',[-40 -20 -8 0 20],'LineWidth',1);

subplot(2,1,2)
semilogx(w,Lph_deg,'b',[wPM wPM w(1)],[0 -180+PM -180+PM],'k-.')
axis([w(1) w(end) -270 0]);
ylabel('Phase (deg)');
xlabel('Frequency (rad/sec)');
set(gca,'YTick',[-270 -180 -90 0],'LineWidth',1);
grid on;


%% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    myprint(1,'PMBode1')
    
    figure(2)
    garyfyFigure
    myprint(2,'PMBode2')
end
